.. _user:

#################
gediDB User Guide
#################

Welcome to the **gediDB User Guide**! This guide provides an overview of the core features of gediDB and walks you through getting started, fundamental concepts, and advanced usage.

.. toctree::
   :caption: Getting Started
   :maxdepth: 1

   why-gedidb
   installing
   quick-overview
   api
   faq
   
.. toctree::
   :caption: Fundamentals
   :maxdepth: 1

   fundamentals
   tiledb_database   

.. toctree::
   :caption: Advanced Usage
   :maxdepth: 1

   database
   tuning-config
   contributing

.. tip::
   Make sure to check the :ref:`faq` section if you encounter any issues while using gediDB!
